@@ -6,16 +6,13 @@
 #' 
 #' @return The method returns a vector containing the symbolic polygonal empirical mean in first and second dimension, respectively.
 #' @examples 
-#' x <- psim(10, 3) #simulate 10 polygons of 3 sides
+#' x <- psim(10, 10) #simulate 10 polygons of 10 sides
 #' pmean(x)
 #' @export
 pmean <- function (polygons){
-  if(length(polygons) < 1){
-    stop("Insert a valid number of polygons!")
-  }
-  first.moment <- lapply(polygons, pmean_id)
-  first.moment <- unlist(first.moment)
-  first.moment <- matrix(first.moment, ncol = 2, byrow = T)
-  first.moment <- c(mean(first.moment[, 1]), mean(first.moment[, 2]))
-  return(first.moment)
+  first_moment <- lapply(polygons, pmean_id)
+  first_moment <- unlist(first_moment)
+  first_moment <- matrix(first_moment, ncol = 2, byrow = T)
+  first_moment <- c(mean(first_moment[, 1]), mean(first_moment[, 2]))
+  return(first_moment)
 }
\ No newline at end of file
